@@ -273,7 +273,7 @@ class MeshVisualization():
     ##################################
     def addKeyPressEvents(self):
         """Method to add all user-defined key-press events"""
-        activeKeys=["m", "d", "space", "x", "y", "z"]                           # define list of keys with active (user-defined) key press events
+        activeKeys=["h", "m", "d", "space", "x", "y", "z"]                      # define list of keys with active (user-defined) key press events
         for key in activeKeys:                                                  # loop over all active keys
             self.plotterObj.add_key_event(key,self._keyPressEvents)             # add corresponding key press events
 
@@ -306,10 +306,22 @@ class MeshVisualization():
     ####################################
     # Method to show command line help #
     ####################################
-    def showCommandLineHelp():
+    def showCommandLineHelp(self):
         """Internal method to show command line help after the rendering window
         is displayed"""
-        pass
+        infoText=("\nUse one of the following key events to control the plot:\n"
+                  "\n"
+                  "\ts \tactivate surface representation of objects\n"
+                  "\tw \tactivate wireframe representation if objects\n"
+                  "\tv \tenable isometric view\n"
+                  "\tx \tset view to y-z-plane\n"
+                  "\ty \tset view to z-x-plane\n"
+                  "\tz \tset view to x-y-plane\n"
+                  "\tm \ttoggle menu\n"
+                  "\tspace \tconfirm menu settings\n"
+                  "\td \trestore default settings\n"
+                  "\tq \tclose rendering window\n")
+        print(infoText)
 
 
 
@@ -364,7 +376,10 @@ class MeshVisualization():
     ##############################################
     def _keyPressEvents(self):
         """Internal method setting up user-defined key-press events"""
-        if self.plotterObj.iren.GetKeySym() == "m":                             # check if "m"-key was pressed
+        if self.plotterObj.iren.GetKeySym() == "h":                             # check if "h"-key was pressed
+            self.showCommandLineHelp()                                          # -> show help
+
+        elif self.plotterObj.iren.GetKeySym() == "m":                           # check if "m"-key was pressed
             self.toggleMenu()                                                   # -> toggle menu
 
         elif self.plotterObj.iren.GetKeySym() == "d":                           # check if "d"-key was pressed
